@@ -6,7 +6,7 @@ use strict;
 use warnings;
 
 # Please see the file VERSIONS.
-use version 0.77; our $VERSION = qv('1.1.2');
+use version 0.77; our $VERSION = qv('1.1.3');
 
 # original S::C (originally used here)
 use Carp;
@@ -22,14 +22,14 @@ use Data::Dumper 'Dumper';
 # debug only
 
 #~ $DB::single=1;                                                           #~
-#~ use feature 'say';               # disable in production                 #~
+#~ use feature 'say';                  # disable in production              #~
 #~ use Smart::Comments '###';       # playing with fire;     debug only     #~
 #~ use Smart::Comments '####';      # playing with fire;     debug only     #~
 #~ use Smart::Comments '#####';     # playing with fire;     debug only     #~
 
 ######## / use ########
 
-#~ say '---| Devel::Comments at line ', __LINE__;                           #~
+#~ say '---| Devel::Comments at line ', __LINE__;                      #~
 
 ######## pseudo-constants section ########
 
@@ -286,7 +286,7 @@ sub _init_state {
 # 
 sub _prefilter {
     
-#~ say '---| Devel::Comments at line ', __LINE__;                           #~
+#~ say '---| Devel::Comments at line ', __LINE__;                      #~
     
     shift;                          # Don't need our own package name
     s/\r\n/\n/g;                    # Handle win32 line endings
@@ -387,17 +387,11 @@ sub _prefilter {
     while (@_) {
         my $arg = shift @_;
 
-        if ($arg =~ m{\A -ENV \Z}xms) {
-            my $env =  $ENV{Smart_Comments} || $ENV{SMART_COMMENTS}
-                    || $ENV{SmartComments}  || $ENV{SMARTCOMMENTS}
-                    ;
-
-            return 0 if !$env;   # i.e. if no filtering ABORT
-
-            if ($env !~ m{\A \s* 1 \s* \Z}xms) {
-                unshift @_, split m{\s+|\s*:\s*}xms, $env;
-            }
-        }
+   if ($arg eq '-ENV') {
+       my $env_filters = _handle_env();
+       return 0 if !$env_filters;  # i.e. if no filtering ABORT
+       unshift @_, @{$env_filters};
+   }
         else {
             push @intros, $arg;
         }
@@ -421,6 +415,76 @@ sub _prefilter {
 };
 ######## /_prefilter ########
 
+######## INTERNAL ROUTINE ########
+# _handle_env
+#
+# Purpose  : Deal with environment variables
+# Params   : *none*
+# Reads    : %ENV
+# Returns  : nothing => no environment variable set
+#          : array ref => a list of things to put onto 
+#            the "intros" array. 
+sub _handle_env {
+    # First look to see if the Devel_Comments variable is set, if so
+    # process it and return.
+    my $dc_env = $ENV{Devel_Comments};
+    if ($dc_env) {
+        return _handle_dc_env($dc_env);
+    }
+    # Now check the multitude of smart comments environment variables.
+    my $sc_env =
+         $ENV{Smart_Comments}
+      || $ENV{SMART_COMMENTS}
+      || $ENV{SmartComments}
+      || $ENV{SMARTCOMMENTS};
+    if ($sc_env) {
+        return _handle_sc_env($sc_env);
+    }
+
+    return;
+}
+######## /_handle_env ########
+
+######## INTERNAL ROUTINE ########
+# _handle_dc_env
+#
+# Purpose  : To process the devel comments environment variable.
+# Params   : A scalar containing the value of the environment variable
+# Returns  : An array ref containing 0 or more ???s
+#            - if the env var just contains a 1 a ref to an empty
+#              array is returned.
+#            - otherwise the variable is split on space or (space
+#              surrounded) colons.
+sub _handle_dc_env {
+    my $env = shift;
+    # For now we can just do the same thing as for a smart comments 
+    # env variable.  In future it would be possible to handle devel
+    # comments environment variables differently.
+    return _handle_sc_env($env);
+}
+
+######## /_handle_dc_env ########
+
+######## INTERNAL ROUTINE ########
+# _handle_sc_env
+#
+# Purpose  : To process the devel comments environment variable.
+# Params   : A scalar containing the value of the environment variable
+# Returns  : An array ref containing 0 or more ???s
+#            - if the env var just contains a 1 a ref to an empty
+#              array is returned.
+#            - otherwise the variable is split on space or (space
+#              surrounded) colons.
+sub _handle_sc_env {
+    my $env = shift;
+    if ( $env !~ m{\A \s* 1 \s* \Z}xms ) {
+        return [ split m{\s+|\s*:\s*}xms, $env ];
+    }
+    return [];
+}
+
+######## /_handle_sc_env ########
+
 sub import;     # FORWARD
 
 ######## EXTERNAL SUB CALL ########
@@ -478,7 +542,7 @@ FILTER {
         open *{caller(1).'::DATA'}, '<', \$DATA or die "Internal error: DATA. $!";
     }
     
-#~ say '---| Devel::Comments at line ', __LINE__;                           #~
+#~ say '---| Devel::Comments at line ', __LINE__;                      #~
     
     # Progress bar on a for loop...
     # Calls _decode_for()
@@ -625,7 +689,7 @@ FILTER {
 #   
 sub import {
     
-#~ say '---| Devel::Comments at line ', __LINE__;                           #~
+#~ say '---| Devel::Comments at line ', __LINE__;                      #~
 
 };
 ######## /import ########
@@ -1411,7 +1475,7 @@ sub Dump_for {
 };
 ######## /Dump_for ########
 
-#~ say '---| Devel::Comments at line ', __LINE__;                           #~
+#~ say '---| Devel::Comments at line ', __LINE__;                      #~
 
 #############################
 ######## END MODULE #########
@@ -1424,7 +1488,7 @@ Devel::Comments - Debug with executable smart comments to logs
 
 =head1 VERSION
 
-This document describes Devel::Comments version 1.1.2
+This document describes Devel::Comments version 1.1.3
 
 =head1 SYNOPSIS
 
@@ -1432,7 +1496,8 @@ This document describes Devel::Comments version 1.1.2
     
     # Dumps...
     my $scalar      = 42;
-    ### $scalar                             # prints to STDERR:    ### $my_scalar: 42
+    ### $scalar                             # prints to STDERR:    
+                                            ### $my_scalar: 42
     
     ### @array                              # dumps more complex 
     ### $HoHoA                              #   data structures, too
@@ -1477,9 +1542,10 @@ disabled at once by commenting out the C<use Devel::Comments> line, whereupon
 they return to being simple, dumb comments. Your debugging code can remain in 
 place, guaranteed harmless, ready for the next development cycle. 
 
-Devel::Comments is a fork of L<Smart::Comments>; current intention is to add new 
-features without breaking backward compatibility. Version 1.1.2 implements the
-'any filehandle' feature, allowing smart output to go to any filehandle 
+Devel::Comments is a fork of L<Smart::Comments>; current intention is to 
+add new features without breaking backward compatibility. 
+Version 1.1.2 implements the 'any filehandle' feature, 
+allowing smart output to go to any filehandle 
 opened for writing. You may instead pass in a filename, which DC will open for 
 you. Future plans include extended calling syntax, numerical level enabling, 
 improved progress bars, dump method callback, and execution of arbitrary code. 
@@ -1973,10 +2039,10 @@ The following table summarizes the behaviour:
          Value of
     $ENV{Devel_Comments}          Equivalent Perl
 
-            1                     use Smart::Comments;
-            0                      no Smart::Comments;
-        '###:####'                use Smart::Comments qw(### ####);
-        '### ####'                use Smart::Comments qw(### ####);
+            1                     use Devel::Comments;
+            0                      no Devel::Comments;
+        '###:####'                use Devel::Comments qw(### ####);
+        '### ####'                use Devel::Comments qw(### ####);
 
 To enable the C<Devel_Comments> environment variable, you need to load the
 module with the C<-ENV> flag:
@@ -2029,7 +2095,18 @@ Not recommended to use DC is combination with other source filters.
 
 =head1 BUGS AND LIMITATIONS
 
-No bugs have been reported on DC 1.1.2. 
+Tellfix is ugly and causes a warning to be raised under some circumstances. 
+Intent is to move off IO::Capture::* altogether in favor of Test::Trap;
+so this issue will not be fixed directly. 
+
+The current testing paradigm is flawed; it has too many dependencies, 
+including perl 5.010. We ship with a cut-down "user" test suite, which should 
+run fine under perl 5.008; this is mostly a rehash of the original 
+Smart::Comments test suite and doesn't fully exercise DC's new features. 
+Those interested may want to run the full test suite found in t/all/. 
+
+A number of features are marked as unimplemented. 
+
 Bugs outstanding against SC 1.0.4 can be found at 
 L<https://rt.cpan.org/Dist/Display.html?Queue=Smart-Comments> and they are 
 probably all present in this version of DC. You are welcome to relist against 
@@ -2053,6 +2130,17 @@ Pass-through execution of arbitrary debugging code.
 Police up scraps of stuff currently left in caller's namespace. Store all 
 state entirely within DC. 
 
+=head1 THANKS
+
+=over
+
+=item *
+
+Mike Stok C<< <MIKESTOK@cpan.org> >> 
+for reporting RT#62599 I<and> fixing it.
+
+=back
+
 =head1 AUTHOR
 
 Xiong Changnian  C<< <XIONG@cpan.org> >>
